@@ -62,18 +62,21 @@ static const gchar *authors[] =	{
 
     /* current maintainer(s) */
 
-    "Cyrille Chépélov <cyrille@chepelov.org>",
+    "Hans Breuer <hans@breuer.org>",
     "Lars R. Clausen <lrclause@cs.uiuc.edu>",
 
     /* other author(s) */
 
+    "Cyrille Chépélov <cyrille@chepelov.org>",
     "James Henstridge <james@daa.com.au>",
     "Jerome Abela <abela@solsoft.fr>",
-    "Hans Breuer <hans@breuer.org>",
     "Emmanuel Briot <briot@volga.gnat.com>",
-    "Fredrik Hallenberg <hallon@debian.org>",   
+    "Fredrik Hallenberg <hallon@debian.org>",
+    "Sameer D. Sahasrabuddhe <sameerds@gmail.com>",
+    "Patrick Hallinan <patrick.j.hallinan@gmail.com>",
+    "Luc Cessieux <cessieux@hotmail.com>",
     "Francis J. Lacoste <francis@contre.com>",
-    "Steffen Macke <sdteffen@web.de>",
+    "Steffen Macke <sdteffen@gmail.com>",
     "Jacek Pliszka <Jacek@Pliszka.fuw.edu.pl>",
     "Henk Jan Priester <hj@justcroft.com>",
     "Alejandro Aguilar Sierra <asierra@servidor.unam.mx>",
@@ -94,6 +97,12 @@ static const gchar *authors[] =	{
     "Vadim Berezniker <vadim@berezniker.com>",
     "Krzysztof Foltman <kfoltman@onet.pl>",
     "W. Borgert <debacle@debian.org>",
+    "Luc Pionchon <luc@handhelds.org>",
+    "Maurizio Tidei <tidei@compal.de>",
+    "Sampo Kellomaki <sampo@iki.fi>",
+    "Grégoire Dooms <dooms@info.ucl.ac.be>",
+    "Moritz Kirmse <momomaniac@gmail.com>",
+    "Robert Staudinger <robert.staudinger@gmail.com>",
     NULL
 };
 
@@ -101,5 +110,6 @@ static const gchar *documentors[] =	{
     "Henry House <hajhouse@houseag.com>",
     "Judith Samson <judith@samsonsource.com>",
     "Kevin Breit <battery841@mypad.com>",
+    "Alan Horkan <horkana@tcd.ie>",
     NULL
 };
