@@ -19,10 +19,10 @@
 #define FOCUS_H
 
 #include "diatypes.h"
-#include "object.h"
 
 struct _Focus {
-  Object *obj;
+  DiaObject *obj;
+  Text *text;
   int has_focus;
   void *user_data; /* To be used by the object using this focus (eg. Text) */
 
@@ -33,8 +33,15 @@ struct _Focus {
 };
 
 void request_focus(Focus *focus);
-Focus *active_focus(void);
-void remove_focus(void);
+Focus *get_active_focus(DiagramData *dia);
+void give_focus(Focus *focus);
+Focus *focus_get_first_on_object(DiaObject *obj);
+Focus *focus_next_on_diagram(DiagramData *dia);
+Focus *focus_previous_on_diagram(DiagramData *dia);
+void remove_focus_on_diagram(DiagramData *dia);
+gboolean remove_focus_object(DiaObject *obj);
+void reset_foci_on_diagram(DiagramData *dia);
+DiaObject* focus_get_object(Focus *focus);
 
 #endif /* FOCUS_H */
 
